==> CGFeedMaker-1.0.14.tar.gz: CGFeedMaker/lang/ext/de_DE.php <==
<?php
$lang['addcategory'] = 'Eine neue Kategorie hinzuf&uuml;gen';
$lang['addedit_feed'] = 'Einen RSS-Feed hinzuf&uuml;gen/bearbeiten';
$lang['addfeed'] = 'Einen neuen Feed hinzuf&uuml;gen';
$lang['areyousure_delete'] = 'Wollen Sie diesen Eintrag wirklich l&ouml;schen?';
$lang['cancel'] = 'Abbrechen';
$lang['categories'] = 'Kategorien';
$lang['current_value'] = 'Aktueller Wert';
$lang['delete'] = 'L&ouml;schen';
$lang['details'] = 'Details ';
$lang['edit'] = 'Bearbeiten';
$lang['error_missingparam'] = 'Ein erforderlicher Parameter oder Wert konnte nicht gefunden werden';
$lang['error_nameexists'] = 'Es existiert bereits ein Eintrag mit diesem Namen';
$lang['error_nocatname'] = 'Bitte legen Sie einen Namen f&uuml;r die Kategorie fest';
$lang['error_nonamegiven'] = 'Sie m&uuml;ssen einen Namen/Alias f&uuml;r den Feed eingeben';
$lang['error_nopermission'] = 'Zugriff verweigert';
$lang['error_notemplate'] = 'Kein Template vorgegeben';
$lang['feeds'] = 'Feeds ';
$lang['feed_copyright'] = 'Feed-Copyright';
$lang['feed_description'] = 'Feed-Beschreibung';
$lang['feed_editor'] = 'Feed-Bearbeiter';
$lang['feed_extension'] = 'Feed-Dateiendung';
$lang['feed_image'] = 'Feed-Bild';
$lang['feed_link'] = 'Feed-Link';
$lang['feed_namealias'] = 'Feed-Name/Alias';
$lang['feed_pageid'] = 'Diese Seite f&uuml;r Links verwenden';
$lang['feed_title'] = 'Feed-Title';
$lang['feed_ttl'] = 'Lebensdauer';
$lang['friendlyname'] = 'Calguys FeedMaker';
$lang['help'] = '<h3>Was macht dieses Modul?</h3>
<p>Mit diesem Modul k&ouml;nnen Sie RSS-Feeds jedes beliebigen Moduls erstellen und verwalten, welches eine Zusammenfassungsansicht unterst&uuml;tzt.</p>
<p>Es unterst&uuml;tzt die Kategorisierung der Feeds sowie die automatische und &quot;manuelle&quot; Erzeugung von Links auf RSS-Feeds.</p>
<p>Pretty URL&#039;s werden unterst&uuml;tzt, wenn diese auf Ihrer Webseite aktiviert sind. - <em>z. Bsp.</em> http://www.ihre-webseite.de/feeds/Feed-Name</p>
<h3>Wie wird es eingesetzt?</h3>
<ul>
<li>Erstens m&uuml;ssen Sie einen neuen Feed erstellen und die erforderlichen Parameter angeben.
  <p>Jedem Feed muss ein Template zugeordnet werden. Das mitgelieferte Template zeigt Ihnen, wie Sie einen RSS-Feed des News-Moduls erzeugen k&ouml;nnen.</p>
  <p>Um Templates f&uuml;r andere Feeds zu erstellen, m&uuml;ssen Sie die Variablen dieses Moduls verwenden. F&uuml;gen Sie hierzu den Tag {get_template_vars} in einer Seite, die dieses Modul verwendet, ein, um zu sehen, welche Variablen Sie in Ihrem Feed-Template verwenden k&ouml;nnen. Um die Ausgabe Ihres Feeds zu kontrollieren, m&uuml;ssen Sie eine Kombination dieser Template-Variablen und einem entsprechend modifizierten Modul-Aufruf im Template verwenden.</p>
</li>
<li>Zweitens sollten Sie einen Tag zur automatischen Erstellung der Feeds an der entsprechenden Stelle einf&uuml;gen.
  <p>Dieser Tag erzeugt automatisch Links in der Ausgabe Ihrer Webseite. Sie k&ouml;nnen diesen Tag im head-Bereich Ihres Seiten-Templates oder aber auch im Bereich &quot;Metadaten&quot; der jeweiligen Seite einf&uuml;gen, um die Links automatisch generieren zu lassen. &Uuml;ber verschiedene Parameters kann dann festgelegt werden, welche Links automatisch f&uuml;r welche Feeds erzeugt werden.<br /></p>
<p>  
<em>Beispiel 1:</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; feed=&#039;meinFeed1,meinFeed2 &#039;}</strong> - erzeugt automatisch Links f&uuml;r die vorgegebenen Feeds.<br />
<em>Beispiel 2:</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; category=&#039;meineKategorie1,meineKategorie2&#039;}</strong> - erzeugt automatisch Links f&uuml;r alle Feeds der vorgegebenen Kategorie(n).</p>
</li>
  <li>Drittens k&ouml;nnen Sie &uuml;ber die rsslink-Aktion Links auf einen bestimmten Feed in Ihre Webseite einf&uuml;gen.<p>Damit wird an der Stelle, wo der Tag eingef&uuml;gt wurde, ein Link auf den vorgegebenen Feed erzeugt.</p>
  <p><em>Beispiel 1:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;meinfeed&#039;}</strong> - Generischer &quot;rsslink&quot; Aufruf
  <br/>
  <em>Beispiel 2:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;meinfeed&#039; imageonly=&#039;&#039; image=&#039;uploads/images/rssNeu.jpg&#039; imageclass=&#039;rssImage&#039;}</strong> - Mit diesem Aufruf wird ein Link angezeigt, der nur ein Bild enth&auml;lt. Insbesondere wird ein von der Voreinstellung abweichendes Bild, welches f&uuml;r diesen Link hochgeladen wurde, sowie eine andere CSS-Klasse verwendet, um das Bild zu formatieren (muss in Ihren Stylesheet definiert sein).  
  <br />
   <em>Beispiel 3:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;meinfeed&#039; text=&#039;RSS-News-Feed&#039; image=&#039;uploads/images/rssNeu.jpg&#039; imageclass=&#039;rssImage&#039; linkclass=&quot;rssLink&quot;}</strong> - Mit diesem Aufruf wird ein von der Voreinstellung abweichender Text f&uuml;r den Link auf den Feed, ein von der Voreinstellung abweichendes Bild, welches f&uuml;r diesen Link hochgeladen wurde, sowie eine andere CSS-Klasse verwendet, um das Bild zu formatieren (muss in Ihren Stylesheet definiert sein)</p>
</li>
  </ul>
<h3>Hinweise:</h3>
<ul>
<li>Wenn Sie die PrettyURLs richtig konfiguriert haben, funktioniert das Modul bestens und erzeugt valide Feeds. Anderenfalls scheinen Atom-Links mit einigen unserer URLs Probleme zu haben.</li>
</ul>
<h3>Support</h3>
<p>Dieses Modul beinhaltet keinen kommerziellen Support. Sie k&ouml;nnen jedoch &uuml;ber folgende M&ouml;glichkeiten Hilfe zu dem Modul erhalten:</p>
<ul>
<li>F&uuml;r die letzte Version dieses Moduls, FAQs, dem Versand eines Fehlerreports oder dem Kauf kommerziellen Support besuchen sie bitte die Projektseite unter <a href="http://dev.cmsmadesimple.org">dev.cmsmadesimple.org</a>.</li>
<li>Eine weitere Diskussion zu diesem Modul ist auch in den Foren von <a href="http://forum.cmsmadesimple.org">CMS Made Simple</a> zu finden.</li>
<li>Der Autor calguy1000, ist h&auml;ufig im <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a> zu finden.</li>
<li>Letztlich erreichen sie den Autor auch &uuml;ber eine direkte Email.</li>  
</ul>
<p>Nach der GPL wird diese Software so ver&ouml;ffentlicht, wie sie ist. Bitte lesen Sie den Lizenztext f&uuml;r den vollen Haftungsausschluss.</p>

<h3>Copyright und Lizenz</h3>
<p>Copyright &copy; 2008, Robert Campbell <a href="mailto:calguy1000@cmsmadesimple.org">calguy1000@cmsmadesimple.org</a>. Alle Rechte vorbehalten.</p>
<p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['info_alias'] = 'Dieser Feed darf nur Zeichen enthalten, die auch in einer URL verwendet werden d&uuml;rfen';
$lang['info_copyright'] = 'Copyright-Vermerk f&uuml;r den Inhalt dieses Channels';
$lang['info_description'] = 'Eine kurze Beschreibung dieses Channels';
$lang['info_editor'] = 'Die Email-Adresse des Bearbeiters dieses Channels';
$lang['info_extension'] = 'Feed-Erweiterung (legt eine Erweiterung f&uuml;r diesen Feed fest, z.Bsp. xml, rss, kml ... ohne Vorgabe wird die voreingestellte RSS-Erweiterung verwendet)';
$lang['info_feed_extension'] = 'Wenn zum Formatieren von PrettyURLs mod_rewrite verwendet wird, kann mit diesem Parameter die Dateiendung des erzeugten Feeds festgelegt werden.';
$lang['info_image'] = 'Legt ein Bild in den Formaten GIF, JPEG oder PNG fest, welches mit diesem Channel angezeigt werden kann';
$lang['info_link'] = 'Die URL der HTML-Webseite, die mit diesem Channel korrespondiert';
$lang['info_pageid'] = 'Die Seite, die f&uuml;r alle Links in diesem Feed verwendet werden soll';
$lang['info_ttl'] = 'Dauer in Minuten, die vorgibt, wie lange ein Channel zwischengespeichert werden kann, bevor dieser vom Urspung neu geladen wird';
$lang['moddescription'] = 'Ein flexibles Werkzeug zum Erstellen und Verwalten von RSS-Feeds';
$lang['name'] = 'Name ';
$lang['param_action'] = 'Legt das Verhalten des Moduls fest. Es gibt f&uuml;r diesen Parameter zwei m&ouml;gliche Werte,  &quot;autodiscovery&quot; und &quot;rsslink&quot;. Mit der autodiscovery-Aktion werden automatisch Links erzeugt, sobald diese vorhanden sind. Diese Aktion sollte im head-Bereich Ihres Templates aufgerufen werden. Die rsslink-Aktion kann verwendet werden, um einen Link auf einen bestimmten Feed zu erzeugen, der dann im Seiteninhalt eingef&uuml;gt werden kann.';
$lang['param_category'] = 'Kann nur mit der autodiscovery-Aktion verwendet werden. Mit diesem Parameter k&ouml;nnen Sie eine mit Kommata getrennte Liste von Feed-Kategorien vorgeben, f&uuml;r die Feed-Links erzeugt werden sollen.';
$lang['param_feed'] = 'Kann mit der rsslink- und der autodiscovery-Aktion verwendet werden. Mit diesem Parameter k&ouml;nnen Sie festlegen, welcher Feed einen Link erzeugen soll. Bei Verwendung der autodiscovery-Aktion kann eine mit Kommata getrennte Liste von Feed-Namen &uuml;bergeben werden.';
$lang['param_image'] = 'Kann mit der rsslink-Aktion verwendet werden. Mit diesem Parameter k&ouml;nnen Sie dem RSS-Feed-Link ein anderes Bild zuordnen.';
$lang['param_imageclass'] = 'Legt eine CSS-Klasse f&uuml;r das ausgegebene Bild eines RSS-Feed-Links fest';
$lang['param_imageonly'] = 'Kann mit der rsslink-Aktion verwendet werden. Mit diesem Parameter k&ouml;nnen Sie festlegen, dass kein Text mit dem Link ausgegeben werden soll.';
$lang['param_linkclass'] = 'Legt eine CSS-Klasse f&uuml;r den Link des RSS-Feeds fest';
$lang['param_urlonly'] = 'Kann nur mit der rsslink-Aktion verwendet werden. Mit diesem Parameter wird nur die URL zum RSS-Feed ausgegeben.';
$lang['param_text'] = 'Kann mit der rsslink-Aktion verwendet werden. Mit diesem Parameter k&ouml;nnen Sie den Text vorgeben, der mit dem Link verkn&uuml;pft werden soll. Ohne diesen Parameter wird der Titel des Feeds verwendet.';
$lang['postinstall'] = 'Das CGFeedMaker-Module wurde installiert';
$lang['postuninstall'] = 'Das CGFeedMaker Module und alle damit verbundenen Daten wurden entfernt';
$lang['really_uninstall'] = 'Wollen Sie wirklich dieses Modul entfernen? Es werden auch alle mit dem Modul verbundenen Daten entfernt.';
$lang['reset_to_factory'] = 'Auf die programmseitigen Voreinstellungen zur&uuml;cksenden';
$lang['settings'] = 'Einstellungen';
$lang['submit'] = 'Absenden';
$lang['template'] = 'Template ';
$lang['template_source'] = 'Template-Source';
$lang['utma'] = '156861353.230875029.1281005888.1281005888.1281005888.1';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1281005888.1.1.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
?>

==> CGFeedMaker-1.0.15.tar.gz: CGFeedMaker/lang/ext/de_DE.php <==
<?php
$lang['addcategory'] = 'Eine neue Kategorie hinzuf&uuml;gen';
$lang['addedit_feed'] = 'Einen RSS-Feed hinzuf&uuml;gen/bearbeiten';
$lang['addfeed'] = 'Einen neuen Feed hinzuf&uuml;gen';
$lang['areyousure_delete'] = 'Wollen Sie diesen Eintrag wirklich l&ouml;schen?';
$lang['cancel'] = 'Abbrechen';
$lang['categories'] = 'Kategorien';
$lang['current_value'] = 'Aktueller Wert';
$lang['delete'] = 'L&ouml;schen';
$lang['details'] = 'Details ';
$lang['edit'] = 'Bearbeiten';
$lang['error_missingparam'] = 'Ein erforderlicher Parameter oder Wert konnte nicht gefunden werden';
$lang['error_nameexists'] = 'Es existiert bereits ein Eintrag mit diesem Namen';
$lang['error_nocatname'] = 'Bitte legen Sie einen Namen f&uuml;r die Kategorie fest';
$lang['error_nonamegiven'] = 'Sie m&uuml;ssen einen Namen/Alias f&uuml;r den Feed eingeben';
$lang['error_nopermission'] = 'Zugriff verweigert';
$lang['error_notemplate'] = 'Kein Template vorgegeben';
$lang['feeds'] = 'Feeds ';
$lang['feed_copyright'] = 'Feed-Copyright';
$lang['feed_description'] = 'Feed-Beschreibung';
$lang['feed_editor'] = 'Feed-Bearbeiter';
$lang['feed_extension'] = 'Feed-Dateiendung';
$lang['feed_image'] = 'Feed-Bild';
$lang['feed_link'] = 'Feed-Link';
$lang['feed_namealias'] = 'Feed-Name/Alias';
$lang['feed_pageid'] = 'Diese Seite f&uuml;r Links verwenden';
$lang['feed_title'] = 'Feed-Title';
$lang['feed_ttl'] = 'Lebensdauer';
$lang['friendlyname'] = 'FeedMaker';
$lang['help'] = '<h3>Was macht dieses Modul?</h3>
<p>Mit diesem Modul k&ouml;nnen Sie RSS-Feeds jedes beliebigen Moduls erstellen und verwalten, welches eine Zusammenfassungsansicht unterst&uuml;tzt.</p>
<p>Es unterst&uuml;tzt die Kategorisierung der Feeds sowie die automatische und &quot;manuelle&quot; Erzeugung von Links auf RSS-Feeds.</p>
<p>Pretty URL&#039;s werden unterst&uuml;tzt, wenn diese auf Ihrer Webseite aktiviert sind. - <em>z. Bsp.</em> http://www.ihre-webseite.de/feeds/Feed-Name</p>
<h3>Wie wird es eingesetzt?</h3>
<ol>
<li>
  <p>Erstellen Sie einen neuen Feed und geben Sie die erforderlichen Parameter an. Jedem Feed muss ein Template zugeordnet werden. Das mitgelieferte Template zeigt Ihnen, wie Sie einen RSS-Feed des News-Moduls erzeugen k&ouml;nnen.</p>
  <p>Um Templates f&uuml;r andere Feeds zu erstellen, m&uuml;ssen Sie die Variablen dieses Moduls verwenden. F&uuml;gen Sie hierzu den Tag {get_template_vars} in einer Seite, die dieses Modul verwendet, ein, um zu sehen, welche Variablen Sie in Ihrem Feed-Template verwenden k&ouml;nnen. Um die Ausgabe Ihres Feeds zu kontrollieren, m&uuml;ssen Sie eine Kombination dieser Template-Variablen und einem entsprechend modifizierten Modul-Aufruf im Template verwenden.</p>
</li>
<li>
  <p>F&uuml;gen sie ein Tag zur automatischen Erstellung der Feeds an der entsprechenden Stelle ein. Dieses Tag erzeugt automatisch Links in der Ausgabe Ihrer Webseite. Sie k&ouml;nnen dieses Tag im head-Bereich Ihrer Seiten-Vorlage oder aber auch im Bereich &bdquo;Metadaten&ldquo; der jeweiligen Seite einf&uuml;gen, um die Links automatisch generieren zu lassen. &Uuml;ber verschiedene Parameter kann dann festgelegt werden, welche Links automatisch f&uuml;r welche Feeds erzeugt werden.</p>
<h4>Beispiele</h4>
<ol>
<li><code>{CGFeedMaker action=&#039;autodiscovery&#039; feed=&#039;meinFeed1,meinFeed2 &#039;}</code> &ndash; erzeugt automatisch Links f&uuml;r die vorgegebenen Feeds.</li>
<li><code>{CGFeedMaker action=&#039;autodiscovery&#039; category=&#039;meineKategorie1,meineKategorie2&#039;}</code> &ndash; erzeugt automatisch Links f&uuml;r alle Feeds der vorgegebenen Kategorie(n).</li>
</ol>
</li>
  <li>&Uuml;ber die rsslink-Aktion Links auf einen bestimmten Feed in Ihre Webseite einf&uuml;gen.<p>Damit wird an der Stelle, wo der Tag eingef&uuml;gt wurde, ein Link auf den vorgegebenen Feed erzeugt.</p>
<h4>Beispiele</h4>
  <ol>
<li><code>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;meinfeed&#039;}</code> &ndash; generischer &bdquo;rsslink&ldquo; Aufruf
  </li>
  <li><code>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;meinfeed&#039; imageonly=&#039;&#039; image=&#039;uploads/images/rssNeu.jpg&#039; imageclass=&#039;rssImage&#039;}</code> &ndash; Mit diesem Aufruf wird ein Link angezeigt, der nur ein Bild enth&auml;lt. Insbesondere wird ein von der Voreinstellung abweichendes Bild, welches f&uuml;r diesen Link hochgeladen wurde, sowie eine andere CSS-Klasse verwendet, um das Bild zu formatieren (muss in Ihren Stylesheet definiert sein).
</li>
<li><code>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;meinfeed&#039; text=&#039;RSS-News-Feed&#039; image=&#039;uploads/images/rssNeu.jpg&#039; imageclass=&#039;rssImage&#039; linkclass=&quot;rssLink&quot;}</code> &ndash; Mit diesem Aufruf wird ein von der Voreinstellung abweichender Text f&uuml;r den Link auf den Feed, ein von der Voreinstellung abweichendes Bild, welches f&uuml;r diesen Link hochgeladen wurde, sowie eine andere CSS-Klasse verwendet, um das Bild zu formatieren (muss in Ihren Stylesheet definiert sein)</li>
</ol>
</li>
  </ol>
<h3>Hinweise:</h3>
<ul>
<li>Wenn Sie die PrettyURLs richtig konfiguriert haben, funktioniert das Modul bestens und erzeugt valide Feeds. Anderenfalls scheinen Atom-Links mit einigen unserer URLs Probleme zu haben.</li>
</ul>
<h3>Support</h3>
<p>Dieses Modul beinhaltet keinen kommerziellen Support. Sie k&ouml;nnen jedoch &uuml;ber folgende M&ouml;glichkeiten Hilfe zu dem Modul erhalten:</p>
<ul>
<li>F&uuml;r die letzte Version dieses Moduls, FAQs, dem Versand eines Fehlerreports oder dem Kauf kommerziellen Support besuchen sie bitte die Projektseite unter <a href="http://dev.cmsmadesimple.org">dev.cmsmadesimple.org</a>.</li>
<li>Eine weitere Diskussion zu diesem Modul ist auch in den Foren von <a href="http://forum.cmsmadesimple.org">CMS Made Simple</a> zu finden.</li>
<li>Der Autor calguy1000, ist h&auml;ufig im <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a> zu finden.</li>
<li>Letztlich erreichen sie den Autor auch &uuml;ber eine direkte Email.</li>  
</ul>
<p>Nach der GPL wird diese Software so ver&ouml;ffentlicht, wie sie ist. Bitte lesen Sie den Lizenztext f&uuml;r den vollen Haftungsausschluss.</p>

<h3>Copyright und Lizenz</h3>
<p>Copyright &copy; 2008, Robert Campbell <a href="mailto:calguy1000@cmsmadesimple.org">calguy1000@cmsmadesimple.org</a>. Alle Rechte vorbehalten.</p>
<p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['info_alias'] = 'Dieser Feed darf nur Zeichen enthalten, die auch in einer URL verwendet werden d&uuml;rfen';
$lang['info_copyright'] = 'Copyright-Vermerk f&uuml;r den Inhalt dieses Channels';
$lang['info_description'] = 'Eine kurze Beschreibung dieses Channels';
$lang['info_editor'] = 'Die Email-Adresse des Bearbeiters dieses Channels';
$lang['info_extension'] = 'Feed-Erweiterung (legt eine Erweiterung f&uuml;r diesen Feed fest, z.Bsp. xml, rss, kml ... ohne Vorgabe wird die voreingestellte RSS-Erweiterung verwendet)';
$lang['info_feed_extension'] = 'Wenn zum Formatieren von PrettyURLs mod_rewrite verwendet wird, kann mit diesem Parameter die Dateiendung des erzeugten Feeds festgelegt werden.';
$lang['info_image'] = 'Legt ein Bild in den Formaten GIF, JPEG oder PNG fest, welches mit diesem Channel angezeigt werden kann';
$lang['info_link'] = 'Die URL der HTML-Webseite, die mit diesem Channel korrespondiert';
$lang['info_pageid'] = 'Die Seite, die f&uuml;r alle Links in diesem Feed verwendet werden soll';
$lang['info_ttl'] = 'Dauer in Minuten, die vorgibt, wie lange ein Channel zwischengespeichert werden kann, bevor dieser vom Urspung neu geladen wird';
$lang['moddescription'] = 'Ein flexibles Werkzeug zum Erstellen und Verwalten von RSS-Feeds';
$lang['name'] = 'Name ';
$lang['param_action'] = 'Legt das Verhalten des Moduls fest. Es gibt f&uuml;r diesen Parameter zwei m&ouml;gliche Werte,  &quot;autodiscovery&quot; und &quot;rsslink&quot;. Mit der autodiscovery-Aktion werden automatisch Links erzeugt, sobald diese vorhanden sind. Diese Aktion sollte im head-Bereich Ihres Templates aufgerufen werden. Die rsslink-Aktion kann verwendet werden, um einen Link auf einen bestimmten Feed zu erzeugen, der dann im Seiteninhalt eingef&uuml;gt werden kann.';
$lang['param_category'] = 'Kann nur mit der autodiscovery-Aktion verwendet werden. Mit diesem Parameter k&ouml;nnen Sie eine mit Kommata getrennte Liste von Feed-Kategorien vorgeben, f&uuml;r die Feed-Links erzeugt werden sollen.';
$lang['param_feed'] = 'Kann mit der rsslink- und der autodiscovery-Aktion verwendet werden. Mit diesem Parameter k&ouml;nnen Sie festlegen, welcher Feed einen Link erzeugen soll. Bei Verwendung der autodiscovery-Aktion kann eine mit Kommata getrennte Liste von Feed-Namen &uuml;bergeben werden.';
$lang['param_image'] = 'Kann mit der rsslink-Aktion verwendet werden. Mit diesem Parameter k&ouml;nnen Sie dem RSS-Feed-Link ein anderes Bild zuordnen.';
$lang['param_imageclass'] = 'Legt eine CSS-Klasse f&uuml;r das ausgegebene Bild eines RSS-Feed-Links fest';
$lang['param_imageonly'] = 'Kann mit der rsslink-Aktion verwendet werden. Mit diesem Parameter k&ouml;nnen Sie festlegen, dass kein Text mit dem Link ausgegeben werden soll.';
$lang['param_linkclass'] = 'Legt eine CSS-Klasse f&uuml;r den Link des RSS-Feeds fest';
$lang['param_urlonly'] = 'Kann nur mit der rsslink-Aktion verwendet werden. Mit diesem Parameter wird nur die URL zum RSS-Feed ausgegeben.';
$lang['param_text'] = 'Kann mit der rsslink-Aktion verwendet werden. Mit diesem Parameter k&ouml;nnen Sie den Text vorgeben, der mit dem Link verkn&uuml;pft werden soll. Ohne diesen Parameter wird der Titel des Feeds verwendet.';
$lang['postinstall'] = 'Das CGFeedMaker-Modul wurde installiert';
$lang['postuninstall'] = 'Das CGFeedMaker-Modul und alle damit verbundenen Daten wurden entfernt';
$lang['really_uninstall'] = 'Wollen Sie wirklich dieses Modul entfernen? Es werden auch alle mit dem Modul verbundenen Daten entfernt.';
$lang['reset_to_factory'] = 'Auf die programmseitigen Voreinstellungen zur&uuml;cksenden';
$lang['settings'] = 'Einstellungen';
$lang['submit'] = 'Absenden';
$lang['template'] = 'Template ';
$lang['template_source'] = 'Template-Quelle';
$lang['utma'] = '156861353.1380513814.1331235085.1331238555.1331243270.3';
$lang['utmz'] = '156861353.1331235085.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
